I think this will be a good module to have io features that can't be added to a given calculator, datamine, or vis.thirdparty collection such as cif/xyz files and pymatgen/ase/jarvis structures. It can also contain shortcuts pointing toward those files. For example, for simmate.io.structures I can have imports pointing toward vasp(POSCAR), castep, cif, pymatgen, ase, and all the different ways to represent a single crystal structure.